@@ -3,9 +3,9 @@
 ## author: Brice Ozenne
 ## created: okt 24 2017 (09:21) 
 ## Version: 
-## last-updated: jan 15 2018 (22:03) 
+## last-updated: Jan 12 2022 (14:47) 
 ##           By: Brice Ozenne
-##     Update #: 14
+##     Update #: 19
 #----------------------------------------------------------------------
 ## 
 ### Commentary: 
@@ -16,8 +16,8 @@
 ### Code:
 
 ## * header
-if(TRUE){ ## already called in test-all.R
-    rm(list = ls())
+## rm(list = ls())
+if(FALSE){ ## already called in test-all.R
     library(testthat)
     library(lavaSearch2)    
 }
@@ -25,6 +25,7 @@ if(TRUE){ ## already called in test-all.R
 lava.options(symbols = c("~","~~"))
 
 context("matrixPower")
+matrixPower <- lavaSearch2:::matrixPower
 
 ## * tests
 M <- matrix(rnorm(2e2),20,10)
@@ -40,5 +41,5 @@ test_that("inverse", {
     expect_equal(Sigma.m1 %*% Sigma,diag(1,NROW(Sigma),NCOL(Sigma)))
 })
 
-#----------------------------------------------------------------------
+##----------------------------------------------------------------------
 ### test-matrixPower.R ends here
